/*============================================================================*/
/*          National Instruments / NI-XNET System Configuration API           */
/*----------------------------------------------------------------------------*/
/*      Copyright (c) National Instruments 2019.  All Rights Reserved.        */
/*----------------------------------------------------------------------------*/
/*                                                                            */
/* Title:   nisyscfg_xnet.h                                                   */
/* Purpose: Header file to extend the NI System Configuration API for NI-XNET */
/*                                                                            */
/*============================================================================*/

#ifndef ___nisyscfg_xnet_h___
#define ___nisyscfg_xnet_h___

#include <nisyscfg.h>

////////////////////////////////////////////////////////////////////////////////
// Enumerations
////////////////////////////////////////////////////////////////////////////////

typedef enum
{
   NISysCfgXnetIntfEnetPortModeDirect = 0,
   NISysCfgXnetIntfEnetPortModeTap    = 1
} NISysCfgXnetIntfEnetPortMode;

typedef enum
{
   NISysCfgXnetIntfEnetPhyStateSlave  = 0,
   NISysCfgXnetIntfEnetPhyStateMaster = 1
} NISysCfgXnetIntfEnetPhyState;

typedef enum
{
   NISysCfgXnetIntfBlinkDisable = 0,
   NISysCfgXnetIntfBlinkEnable  = 1
} NISysCfgXnetIntfBlink;

typedef enum
{
   NISysCfgXnetIntfProtocolCan     = 0,
   NISysCfgXnetIntfProtocolFlexRay = 1,
   NISysCfgXnetIntfProtocolLin     = 2,
   NISysCfgXnetIntfProtocolUnknown = 0xFFFFFFFE
} NISysCfgXnetIntfProtocol;

typedef enum
{
   NISysCfgXnetIntfCanTransceiverCapabilityHs           = 0,
   NISysCfgXnetIntfCanTransceiverCapabilityLs           = 1,
   NISysCfgXnetIntfCanTransceiverCapabilityXs           = 3,
   NISysCfgXnetIntfCanTransceiverCapabilityXsWithHsOrLs = 4
} NISysCfgXnetIntfCanTransceiverCapability;

typedef enum
{
   NISysCfgXnetIntfDongleIdLsCan            = 1,
   NISysCfgXnetIntfDongleIdHsCan            = 2,
   NISysCfgXnetIntfDongleIdSwCan            = 3,
   NISysCfgXnetIntfDongleIdXsCan            = 4,
   NISysCfgXnetIntfDongleIdLin              = 6,
   NISysCfgXnetIntfDongleIdDonglelessDesign = 13,
   NISysCfgXnetIntfDongleIdUnknown          = 14
} NISysCfgXnetIntfDongleId;

typedef enum
{
   NISysCfgXnetIntfDongleStateNoDongleNoExternalPower   = 1,
   NISysCfgXnetIntfDongleStateNoDongleHasExternalPower  = 2,
   NISysCfgXnetIntfDongleStateHasDongleNoExternalPower  = 3,
   NISysCfgXnetIntfDongleStateReady                     = 4,
   NISysCfgXnetIntfDongleStateBusy                      = 5,
   NISysCfgXnetIntfDongleStateCommError                 = 13,
   NISysCfgXnetIntfDongleStateOvercurrent               = 14
} NISysCfgXnetIntfDongleState;

typedef enum
{
   NISysCfgXnetIntfEnetLinkSpeedLinkDown = 0,
   NISysCfgXnetIntfEnetLinkSpeed100Mbps  = 1,
   NISysCfgXnetIntfEnetLinkSpeed1000Mbps = 2
} NISysCfgXnetIntfEnetLinkSpeed;

typedef enum
{
   NISysCfgXnetIntfEnetJumboFramesDisabled  = 0,
   NISysCfgXnetIntfEnetJumboFrames9018Bytes = 1
} NISysCfgXnetIntfEnetJumboFrames;

typedef enum
{
   NISysCfgXnetIntfEnetInterruptModerationOff    = 0,
   NISysCfgXnetIntfEnetInterruptModerationLow    = 1,
   NISysCfgXnetIntfEnetInterruptModerationMedium = 2,
   NISysCfgXnetIntfEnetInterruptModerationHigh   = 3
} NISysCfgXnetIntfEnetInterruptModeration;

////////////////////////////////////////////////////////////////////////////////
// Properties
////////////////////////////////////////////////////////////////////////////////

typedef enum
{
   // Read-only device properties
   NISysCfgXnetResourcePropertyDeviceNumberPorts                         = 167780352, // unsigned int

   // Read-only port properties
   NISysCfgXnetResourcePropertyIntfPortNumber                            = 167845888, // unsigned int
   NISysCfgXnetResourcePropertyIntfProtocol                              = 167796737, // NISysCfgXnetIntfProtocol
   NISysCfgXnetResourcePropertyIntfCanTerminationCapability              = 167849984, // NISysCfgBool
   NISysCfgXnetResourcePropertyIntfCanTransceiverCapability              = 167792641, // NISysCfgXnetIntfCanTransceiverCapability
   NISysCfgXnetResourcePropertyIntfDongleId                              = 167813120, // NISysCfgXnetIntfDongleId
   NISysCfgXnetResourcePropertyIntfDongleState                           = 167809024, // NISysCfgXnetIntfDongleState

   // Write-only port properties
   NISysCfgXnetResourcePropertyIntfBlink                                 = 167817216, // NISysCfgXnetIntfBlink

   // Read-only Automotive Ethernet port properties
   NISysCfgXnetResourcePropertyIntfEnetMacAddr                           = 167841792, // char *
   NISysCfgXnetResourcePropertyIntfEnetIpV4Addr                          = 167854080, // char *
   NISysCfgXnetResourcePropertyIntfEnetOsAdapterName                     = 167858176, // char *
   NISysCfgXnetResourcePropertyIntfEnetOsAdapterDesc                     = 167862272, // char *
   NISysCfgXnetResourcePropertyIntfEnetLinkSpeed                         = 167874560, // NISysCfgXnetIntfEnetLinkSpeed
   NISysCfgXnetResourcePropertyIntfEnetSleepCapability                   = 167911424, // NISysCfgXnetIntfEnetSleepCapability
   NISysCfgXnetResourcePropertyIntfEnetPhyPowerMode                      = 167915520, // NISysCfgXnetIntfEnetPhyPowerMode

   // Read/Write Automotive Ethernet port properties
   NISysCfgXnetResourcePropertyIntfEnetPhyState                          = 167837696, // NISysCfgXnetIntfEnetPhyState
   NISysCfgXnetResourcePropertyIntfEnetPortMode                          = 167833600, // NISysCfgXnetIntfEnetPortMode
   NISysCfgXnetResourcePropertyIntfEnetLinkSpeedConfigured               = 167866368, // NISysCfgXnetIntfEnetLinkSpeed
   NISysCfgXnetResourcePropertyIntfEnetJumboFrames                       = 167903232, // NISysCfgXnetIntfEnetJumboFrames
   NISysCfgXnetResourcePropertyIntfEnetInterruptModeration               = 167878656, // NISysCfgXnetIntfEnetInterruptModeration
   NISysCfgXnetResourcePropertyIntfEnetSleepCapabilityConfigured         = 167907328, // NISysCfgXnetIntfEnetSleepCapabilityConfigured

   // Read-only device properties
   NISysCfgXnetResourcePropertyIpStackInfoJson                          = 167882752, // char *
   NISysCfgXnetResourcePropertyIpStackInfoText                          = 167886848  // char *
} NISysCfgXnetResourceProperty;

typedef enum
{
   // Write-only device properties
   NISysCfgXnetFilterPropertyDeviceNumberPorts                           = 167780352, // unsigned int

   // Write-only port properties
   NISysCfgXnetFilterPropertyIntfPortNumber                              = 167845888, // unsigned int
   NISysCfgXnetFilterPropertyIntfProtocol                                = 167796737, // NISysCfgXnetIntfProtocol
   NISysCfgXnetFilterPropertyIntfCanTransceiverCapability                = 167792641, // NISysCfgXnetIntfCanTransceiverCapability
   NISysCfgXnetFilterPropertyIntfCanTerminationCapability                = 167849984, // NISysCfgBool
   NISysCfgXnetFilterPropertyIntfDongleId                                = 167813120, // NISysCfgXnetIntfDongleId

   // Write-only Automotive Ethernet port properties
   NISysCfgXnetFilterPropertyIntfEnetPhyState                            = 167837696, // NISysCfgXnetIntfEnetPhyState
   NISysCfgXnetFilterPropertyIntfEnetPortMode                            = 167833600, // NISysCfgXnetIntfEnetPortMode
   NISysCfgXnetFilterPropertyIntfEnetLinkSpeedConfigured                 = 167866368  // NISysCfgXnetIntfEnetLinkSpeed
} NISysCfgXnetFilterProperty;

#endif
